@@ -122,7 +122,11 @@ class EmpresaLog(models.Model):
 
 class ContatoLog(models.Model):
     celular = models.CharField(max_length=50, null=True)
+    celular_ddd = models.CharField(max_length=3, null=True)
+
     telefone = models.CharField(max_length=50, null=True)
+    telefone_ddd = models.CharField(max_length=3, null=True)
+
     email = models.EmailField(max_length=200, null=True)
 
     class Meta(Log.Meta):
